@@ -14,7 +14,7 @@
 
    Copyright (C) 1999 Chris Black.
    Copyright (C) 2000 Philippe Kehl.
-   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Arthur de Jong.
+   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Arthur de Jong.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -123,8 +123,8 @@ static void display_version(FILE *fp)
 {
   fprintf(fp,"%s\n",PACKAGE_STRING);
   fprintf(fp,"Written by Chris Black, Philippe Kehl and Arthur de Jong.\n\n");
-  fprintf(fp,"Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Chris Black,\n"
-             "Philippe Kehl and Arthur de Jong.\n"
+  fprintf(fp,"Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Chris\n"
+             "Black, Philippe Kehl and Arthur de Jong.\n"
              "This is free software; see the source for copying conditions.  There is NO\n"
              "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 }
@@ -314,7 +314,8 @@ static void exithandler(void)
 static void handleconnection(int csock,const struct cvsd_cfg *cfg)
 {
   pid_t cpid;
-  int i,m;
+  int i;
+  long m;
 
   /* we have a possible race here? (probably atomic) */
   cvsd_numchildren++;
@@ -335,6 +336,10 @@ static void handleconnection(int csock,const struct cvsd_cfg *cfg)
     }
     /* close all other file descriptors */
     m=sysconf(_SC_OPEN_MAX);
+    /* if the system does not have OPEN_MAX just close the first 32 and
+       hope we closed enough */
+    if (m<0)
+      m=32;
     for (i=3;i<m;i++)
       close(i);
     /* execute cvs */
